@@ -7,7 +7,7 @@
 
 static char basever[] = "8.3.0";
 static char datestamp[] = "20190222";
-static char devphase[] = "Sailfish OS gcc 8.3.0-4";
+static char devphase[] = "Aurora OS gcc 8.3.0-4";
 static char revision[] = "";
 
 /* FIXME plugins: We should make the version information more precise.
